@@ -18,8 +18,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -78,7 +78,9 @@ class LambdaDestination(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: aws_cdk.core.Construct, log_group: aws_cdk.aws_logs.ILogGroup
+        self,
+        scope: aws_cdk.core.Construct,
+        log_group: aws_cdk.aws_logs.ILogGroup,
     ) -> aws_cdk.aws_logs.LogSubscriptionDestinationConfig:
         """Return the properties required to send subscription events to this destination.
 
